2009 Pacific-Asia Knowledge Discovery and Data Mining conference (PAKDD) competition

This is a copy of the PAKDD dataset.
http://sede.neurotech.com.br:443/PAKDD2009/


Description:

Credit Risk Assessment on a Private Label Credit Card Application

The offer of credit for potential clients is a very important service for stimulating consumption in the market. Despite being among the oldest application domains for data mining (from the times when not even the name "data mining" existed), there are some difficulties related to credit scoring which are often overlooked by modelers, namely.

    In general, there are only data about the company's clients for modeling, but not about the rejected applicants. These represent a sample of the potential clients (market) that is strongly biased given that a systematic procedure focused on the problem target (payment default) has been applied for selection.

    Also, the data has been collected from a time interval in the past for developing a model to be applied in a future time. Not considering any drastic change in the economy, gradual market changes occur and reduce the performance of the model estimated on the modeling data set.

Another important aspect, often, overlooked by scientists is the series of impacts of re-calibrating the solution already in operation (retraining and tuning the decision threshold) for correcting the degradation to improve or, at least, preserve the existing performance. This task is particularly risky when the credit is lent for long term payment (such as mortgages). Furthermore, the score generated by such a model may be in use within the company for several decision making processes such as, for instance, the marketing/sales department trading off market expansion with risk increase or as input to other decision systems such as debt collection scoring models.

This competition focuses on the credit scoring model's robustness against performance degradation caused by market gradual changes along few years of business operation.

Participants will download a labeled data set from one year period for modeling, will submit scores to the leaderboard dataset from one year later, and the competition results will be assessed on scores submitted for a prediction dataset starting from three years later. These data sets come from the private label credit card operation of a major Brazilian retail chain, along stable inflation condition (2003-2008).

The official performance metrics will be the area under the ROC curve and a Java routine for calculating it is available for download.



Attribute Information:

VARIABLES	;	DESCRIPTION
ID_CLIENT	;	Sequential number for the applicant (to be used as a key)
ID_SHOP	;	Shop code where the application has been made
SEX	;	M=Male, F=Female
MARITAL_STATUS	;	S=Single, C=Married, D=Divorced, V=Widow, O=Other
AGE	;	Applicant´s age
QUANT_DEPENDANTS	;	Quantity of applicant´s dependants
EDUCATION	;	Applicant's education level
FLAG_RESIDENCIAL_PHONE	;	Y=Yes, N=No; If the applicant possesses a residencial phone
AREA_CODE_RESIDENCIAL_PHONE	;	Modified residencial phone area code
PAYMENT_DAY	;	Fixed month day selected for the eventual monthly payment
SHOP_RANK	;	Company´s rating for the shop in comercial terms
RESIDENCE_TYPE	;	P=Owned, A=Rented, C=Parents' House, O=Other
MONTHS_IN_RESIDENCE	;	Time in the current residence in months
FLAG_MOTHERS_NAME	;	Y=Yes, N=No; If the applicant had filled the father's name in the form
FLAG_FATHERS_NAME	;	Y=Yes, N=No; If the applicant had filled the mother's name in the form
FLAG_RESIDENCE_TOWN=WORKING_TOWN	;	Y=Yes, N=No; If the applicant works in the same town where lives
FLAG_RESIDENCE_STATE=WORKING_STATE	;	Y=Yes, N=No; If the applicant works in the same state where lives
MONTHS_IN_THE_JOB	;	Time in the current job in months
PROFESSION_CODE	;	Applicant´s profession code
MATE_INCOME	;	Applicant's mate monthly net income in Brazilian currency (R$)
FLAG_RESIDENCIAL_ADDRESS=POSTAL_ADDRESS	;	Y=Yes, N=No; If the applicant receives the post in the same address where lives
FLAG_OTHER_CARD	;	Y=Yes, N=No; If the applicant possesses another credit or private label card
QUANT_BANKING_ACCOUNTS	;	Quantity of applicant´s banking accounts
PERSONAL_REFERENCE_#1	;	First name of the personal reference #1 (in Portuguese)
PERSONAL_REFERENCE_#2	;	First name of the personal reference #1 (in Portuguese)
FLAG_MOBILE_PHONE	;	Y=Yes, N=No; If the applicant possesses a mobile phone
FLAG_CONTACT_PHONE	;	Y=Yes, N=No; If the applicant possesses a contact phone
PERSONAL_NET_INCOME	;	Applicant's personal monthly net income in Brazilian currency (R$)
COD_APPLICATION_BOOTH	;	Booth code where applicantion was handed in
QUANT_ADDITIONAL_CARDS_IN_THE_APPLICATION	;	Quantity of additional cards asked for in the same application form
FLAG_CARD_INSURANCE_OPTION	;	Y=Yes, N=No; If the applicant asked for card insurance service
TARGET_LABEL_BAD=1	;	Target Variable: BAD=1, GOOD=0

